
import {axisLeft, 
        axisRight,
        axisBottom,
        select,
        csv,
        scaleLinear,
        extent,
        scalePoint,
        format
       } from "d3";

const svg = d3.select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

svg.style('background-color',"white");

const render = data => {
  
const margin = {top: 60, right: 20, bottom: 80, left: 140};
const innerWidth=width-margin.left-margin.right;
const innerHeight=height-margin.top-margin.bottom;

//     d.mpg = +d.mpg;
//     d.cylinders = +d.cylinders;
//     d.displacement = +d.displacement ;
//     d.horsepower = +d.horsepower;
//     d.weight = +d.weight;
//     d.acceleration = +d.acceleration;
//     d.year = +d.year;
  
  const xAxisLabel = "weight";
  const yAxisLabel ="acceleration"
  const topLabel = "HorsePower vs Weight"
  
  const xValue =d=>d.mpg;
  const yValue = d=>d.acceleration;
  const xScale = scaleLinear()
  								.domain(extent(data, xValue))
  								.range([0,innerWidth]).nice();
  
  const yScale = scaleLinear()
  								.domain(extent(data, yValue))
  								.range([0,innerHeight]);
  
  
  const g= svg.append('g')
  						.attr('transform',`translate( ${margin.left}, ${margin.top})`);
  
  const formatedNumber =number=> format('0.3s')(number).replace('G','B');
  
  const xAxis = axisBottom(xScale).tickFormat(formatedNumber).tickSize(-innerHeight);
  
  const yAxis = axisLeft(yScale).tickSize(-innerWidth);
  
  g.append('text').attr('y',-20).attr('x',200).text(topLabel);
  
  
	const yAxisG =	g.append('g').call(yAxis);
  
  yAxisG.selectAll('.domain').remove();
  yAxisG.append('text')
    .attr('class','axis-label')
    .attr('x',-innerHeight/2)
    .attr('y',-40)
    .attr('text-anchor','middle')
    .attr('fill','black')
  	.attr('transform', `rotate(-90)`)
    .text(yAxisLabel);
  
  const xAxisG = g.append('g')
  	.call(xAxis)
		.attr('transform',`translate( 0 , ${innerHeight})`)
  
  xAxisG.selectAll('.domain')
  	.remove() ;
    
	xAxisG.append('text')
    .attr('class','axis-label')
    .attr('y',50)
    .attr('x',innerWidth/2)
  	.attr('text-anchor','middle')
    .attr('fill','black')
    .text(xAxisLabel);
  
  g.selectAll('circle')
    .data(data)
  	.enter()
    .append('circle')
  	.attr('cx',d=>xScale(xValue(d)))
  	.attr('cy',d=>yScale(yValue(d)))
  	.attr('r', 10);
};


csv('data.csv').then(data=> {
  data.forEach(d=> {
    d.mpg = +d.mpg;
    d.cylinders = +d.cylinders;
    d.displacement = +d.displacement ;
    d.horsepower = +d.horsepower;
    d.weight = +d.weight;
    d.acceleration = +d.acceleration;
    d.year = +d.year;
  });
  render(data);
});
